"""
OpenAtlas Agent - Autonomous Browser Agent

An autonomous browser agent with web search and interactive browsing capabilities.
"""

__version__ = "1.0.7"
__author__ = "Harish Santhanalakshmi Ganesan"
__license__ = "MIT"

from .agent import CombinedAgent

__all__ = ["CombinedAgent"]
